UniqueValidator<T> class

UniqueValidator extends TranslatedValidator to validate if a value is unique within a specified list of values.

Parameters:

  • values The list of values to check against for uniqueness.
  • errorText The error message returned if the validation fails.
  • checkNullOrEmpty Whether to check if the value is null or empty.
Inheritance

Constructors

UniqueValidator(List<T> values, {String? errorText, bool checkNullOrEmpty = true})
Constructor for the unique value validator.
const

Properties

checkNullOrEmpty → bool
Whether to check if the value is null or empty.
finalinherited
errorText → String
The error message returned if the value is invalid.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
translatedErrorText → String
The translated error message returned if the value is invalid.
no setteroverride
values → List<T>
The list of values to check against for uniqueness.
final

Methods

isNullOrEmpty(T? valueCandidate) → bool
Checks if the value is null or empty. Returns true if the value is null or empty, otherwise false. The value is considered empty if it is a String, Iterable, or Map and it is empty or contains only whitespace characters. If the value is not a String, Iterable, or Map, it is considered empty if it is null.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validate(T? valueCandidate) → String?
Validates the value and checks if it is null or empty.
inherited
validateValue(T valueCandidate) → String?
Validates the value. Returns null if the value is valid, otherwise an error message. Call validate() instead of this method when using the validator.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited